@@ -9,7 +9,7 @@ fn main() -> Result<(), String> {
     let mut enigo = Enigo::new();
     let opt = Opt::from_args();
     if opt.debug {
-        println!("\nOptions: {:#?}", opt);
+        println!("Options: {:#?}\n", opt);
     }
     let mut rng = rand::thread_rng();
 
